@@ -15,6 +15,10 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdlib.h>
 
 #include <gio/gio.h>
@@ -28,23 +32,22 @@
 typedef struct _DwellData DwellData;
 struct _DwellData
 {
-    GSettings   *mt_settings;
-    GSettings   *gsd_settings;
-    GDBusProxy  *proxy;
-    GtkBuilder  *ui;
-    GtkWidget   *box;
-    GtkWidget   *ct_box;
-    GtkWidget   *enable;
-    GtkWidget   *button;
-    GdkPixbuf   *click[4];
-    gint         button_width;
-    gint         button_height;
-    MtClickType  cct;
-    gboolean     active;
-    GTimer      *timer;
-    guint        tid;
-    gdouble      delay;
-    gdouble      elapsed;
+    GSettings          *settings;
+    GDBusProxy         *proxy;
+    GtkBuilder         *ui;
+    GtkWidget          *box;
+    GtkWidget          *ct_box;
+    GtkWidget          *enable;
+    GtkWidget          *button;
+    GdkPixbuf          *click[4];
+    gint                button_width;
+    gint                button_height;
+    MtDwellClickType    cct;
+    gboolean            active;
+    GTimer             *timer;
+    guint               tid;
+    gdouble             delay;
+    gdouble             elapsed;
 };
 
 static const gchar *img_widgets[] =
@@ -63,25 +66,28 @@ static const gchar *img_widgets_v[] =
     "single_click_img_v"
 };
 
-static void preferences_dialog (BonoboUIComponent *component,
-                                gpointer           data,
-                                const char        *cname);
-static void help_dialog        (BonoboUIComponent *component,
-                                DwellData         *dd,
-                                const char        *cname);
-static void about_dialog       (BonoboUIComponent *component,
-                                DwellData         *dd,
-                                const char        *cname);
-
-static const BonoboUIVerb menu_verb[] =
+static const gchar menu_xml[] =
 {
-    BONOBO_UI_UNSAFE_VERB ("PropertiesVerb", preferences_dialog),
-    BONOBO_UI_UNSAFE_VERB ("HelpVerb", help_dialog),
-    BONOBO_UI_UNSAFE_VERB ("AboutVerb", about_dialog),
-    BONOBO_UI_VERB_END
+    "<menuitem name=\"item1\" action=\"Preferences\" />"
+    "<separator/>"
+    "<menuitem name=\"item2\" action=\"Help\" />"
+    "<menuitem name=\"item3\" action=\"About\" />"
 };
 
-static void button_cb (GtkToggleButton *button, DwellData *dd);
+static void button_cb          (GtkToggleButton *button, DwellData *dd);
+static void preferences_dialog (GtkAction *action, DwellData *dd);
+static void help_dialog        (GtkAction *action, DwellData *dd);
+static void about_dialog       (GtkAction *action, DwellData *dd);
+
+static const GtkActionEntry menu_actions[] =
+{
+    { "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, NULL,
+      G_CALLBACK (preferences_dialog) },
+    { "Help", GTK_STOCK_HELP, N_("_Help"), NULL, NULL,
+      G_CALLBACK (help_dialog) },
+    { "About", GTK_STOCK_ABOUT, N_("_About"), NULL, NULL,
+      G_CALLBACK (about_dialog) }
+};
 
 static void
 update_sensitivity (DwellData *dd)
@@ -90,8 +96,8 @@ update_sensitivity (DwellData *dd)
     gint mode;
 
     dwell = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dd->enable));
-    mode = g_settings_get_int (dd->mt_settings, KEY_DWELL_MODE);
-    sensitive = dd->active && dwell && mode == DWELL_MODE_CTW;
+    mode = g_settings_get_enum (dd->settings, KEY_DWELL_MODE);
+    sensitive = dd->active && dwell && mode == G_DESKTOP_MOUSE_DWELL_MODE_WINDOW;
     gtk_widget_set_sensitive (dd->ct_box, sensitive);
 }
 
@@ -119,8 +125,8 @@ mt_proxy_owner_notify (GObject    *object,
 }
 
 static void
-handle_click_type_changed (DwellData  *dd,
-                           MtClickType click_type)
+handle_click_type_changed (DwellData       *dd,
+                           MtDwellClickType click_type)
 {
     GtkToggleButton *button;
     GSList *group;
@@ -187,8 +193,8 @@ mt_proxy_init (DwellData *dd)
 }
 
 static void
-mt_proxy_set_click_type (GDBusProxy *proxy,
-                         MtClickType click_type)
+mt_proxy_set_click_type (GDBusProxy      *proxy,
+                         MtDwellClickType click_type)
 {
     GVariant *ct;
 
@@ -218,8 +224,7 @@ do_not_eat (GtkWidget *widget, GdkEventButton *bev, gpointer user)
 static void
 enable_dwell_changed (GtkToggleButton *button, DwellData *dd)
 {
-    g_settings_set_boolean (dd->gsd_settings,
-                            KEY_DWELL_ENABLED,
+    g_settings_set_boolean (dd->settings, KEY_DWELL_ENABLED,
                             gtk_toggle_button_get_active (button));
 }
 
@@ -385,8 +390,6 @@ applet_orient_changed (PanelApplet *applet,
                        guint        orient,
                        DwellData   *dd)
 {
-    gboolean dwell;
-
     gtk_container_remove (GTK_CONTAINER (applet), g_object_ref (dd->box));
 
     switch (orient)
@@ -418,8 +421,9 @@ applet_orient_changed (PanelApplet *applet,
         g_object_unref (dd->box);
     }
 
-    dwell = g_settings_get_boolean (dd->gsd_settings, KEY_DWELL_ENABLED);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dd->enable), dwell);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dd->enable),
+                                  g_settings_get_boolean (dd->settings,
+                                                          KEY_DWELL_ENABLED));
     update_sensitivity (dd);
 }
 
@@ -433,8 +437,7 @@ applet_unrealized (GtkWidget *widget, DwellData *dd)
             g_object_unref (dd->click[i]);
 
     g_object_unref (dd->ui);
-    g_object_unref (dd->mt_settings);
-    g_object_unref (dd->gsd_settings);
+    g_object_unref (dd->settings);
     g_object_unref (dd->proxy);
     g_timer_destroy (dd->timer);
 
@@ -442,34 +445,28 @@ applet_unrealized (GtkWidget *widget, DwellData *dd)
 }
 
 static void
-preferences_dialog (BonoboUIComponent *component,
-                    gpointer           data,
-                    const char        *cname)
+preferences_dialog (GtkAction *action, DwellData *dd)
 {
     GError *error = NULL;
 
     if (!g_spawn_command_line_async ("gnome-control-center universal-access", &error))
     {
-         mt_common_show_dialog (_("Failed to Open the Univeral Access Panel"),
+         mt_common_show_dialog (_("Failed to Open the Universal Access Panel"),
                                 error->message,
-                                MT_MESSAGE_WARNING);
+                                MT_MESSAGE_TYPE_WARNING);
          g_error_free (error);
     }
 }
 
 static void
-help_dialog (BonoboUIComponent *component,
-             DwellData         *dd,
-             const char        *cname)
+help_dialog (GtkAction *action, DwellData *dd)
 {
     mt_common_show_help (gtk_widget_get_screen (dd->box),
                          gtk_get_current_event_time ());
 }
 
 static void
-about_dialog (BonoboUIComponent *component,
-              DwellData         *dd,
-              const char        *cname)
+about_dialog (GtkAction *action, DwellData *dd)
 {
     gtk_window_present (GTK_WINDOW (WID ("about")));
 }
@@ -581,13 +578,10 @@ fill_applet (PanelApplet *applet)
     DwellData *dd;
     GError *error = NULL;
     GtkWidget *about;
+    GtkActionGroup *group;
     PanelAppletOrient orient;
 
-    bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
-    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
-
-    g_set_application_name (_("Dwell Click"));
+    g_set_application_name (_("Dwell Click Applet"));
     gtk_window_set_default_icon_name (MT_ICON_NAME);
 
     dd = g_slice_new0 (DwellData);
@@ -609,7 +603,7 @@ fill_applet (PanelApplet *applet)
     /* dbus */
     mt_proxy_init (dd);
 
-    dd->cct = DWELL_CLICK_TYPE_SINGLE;
+    dd->cct = MT_DWELL_CLICK_TYPE_SINGLE;
     dd->timer = g_timer_new ();
 
     /* about dialog */
@@ -621,24 +615,22 @@ fill_applet (PanelApplet *applet)
                       G_CALLBACK (about_response), dd);
 
     /* gsettings */
-    dd->mt_settings = g_settings_new (MT_SCHEMA_ID);
-    g_signal_connect (dd->mt_settings, "value::" KEY_DWELL_MODE,
+    dd->settings = g_settings_new (A11Y_MOUSE_SCHEMA_ID);
+    g_signal_connect (dd->settings, "changed::" KEY_DWELL_ENABLED,
+                      G_CALLBACK (dwell_enabled_changed), dd);
+    g_signal_connect (dd->settings, "changed::" KEY_DWELL_MODE,
                       G_CALLBACK (dwell_mode_changed), dd);
-    g_signal_connect (dd->mt_settings, "value::" KEY_DWELL_TIME,
+    g_signal_connect (dd->settings, "changed::" KEY_DWELL_TIME,
                       G_CALLBACK (dwell_time_changed), dd);
 
-    dd->gsd_settings = g_settings_new (GSD_MOUSE_SCHEMA_ID);
-    g_signal_connect (dd->gsd_settings, "value::" KEY_DWELL_ENABLED,
-                      G_CALLBACK (dwell_enabled_changed), dd);
-
     /* icons */
-    dd->click[DWELL_CLICK_TYPE_SINGLE] =
+    dd->click[MT_DWELL_CLICK_TYPE_SINGLE] =
         gdk_pixbuf_new_from_file (DATADIR "/single-click.png", NULL);
-    dd->click[DWELL_CLICK_TYPE_DOUBLE] =
+    dd->click[MT_DWELL_CLICK_TYPE_DOUBLE] =
         gdk_pixbuf_new_from_file (DATADIR "/double-click.png", NULL);
-    dd->click[DWELL_CLICK_TYPE_DRAG] =
+    dd->click[MT_DWELL_CLICK_TYPE_DRAG] =
         gdk_pixbuf_new_from_file (DATADIR "/drag-click.png", NULL);
-    dd->click[DWELL_CLICK_TYPE_RIGHT] =
+    dd->click[MT_DWELL_CLICK_TYPE_RIGHT] =
         gdk_pixbuf_new_from_file (DATADIR "/right-click.png", NULL);
 
     /* applet initialization */
@@ -646,15 +638,19 @@ fill_applet (PanelApplet *applet)
                             PANEL_APPLET_EXPAND_MINOR |
                             PANEL_APPLET_HAS_HANDLE);
     panel_applet_set_background_widget (applet, GTK_WIDGET(applet));
-    panel_applet_setup_menu_from_file (applet,
-                                       DATADIR, "DwellClick.xml",
-                                       NULL, menu_verb, dd);
 
     g_signal_connect (applet, "change-orient",
                       G_CALLBACK (applet_orient_changed), dd);
     g_signal_connect (applet, "unrealize",
                       G_CALLBACK (applet_unrealized), dd);
 
+    /* context menu */
+    group = gtk_action_group_new ("actions");
+    gtk_action_group_set_translation_domain (group, GETTEXT_PACKAGE);
+    gtk_action_group_add_actions (group, menu_actions, 3, dd);
+    panel_applet_setup_menu (applet, menu_xml, group);
+    g_object_unref (group);
+
     /* check initial orientation */
     orient = panel_applet_get_orient (applet);
     if (orient == PANEL_APPLET_ORIENT_UP ||
@@ -673,9 +669,9 @@ fill_applet (PanelApplet *applet)
         dd->button = WID ("single_click_v");
     }
 
-    dd->delay = g_settings_get_double (dd->mt_settings, KEY_DWELL_TIME);
+    dd->delay = g_settings_get_double (dd->settings, KEY_DWELL_TIME);
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dd->enable), 
-                                  g_settings_get_boolean (dd->gsd_settings,
+                                  g_settings_get_boolean (dd->settings,
                                                           KEY_DWELL_ENABLED));
 
     setup_box (dd);
@@ -689,15 +685,14 @@ fill_applet (PanelApplet *applet)
 static gboolean
 applet_factory (PanelApplet *applet, const gchar *iid, gpointer data)
 {
-    if (!g_str_equal (iid, "OAFIID:DwellClickApplet"))
+    if (!g_str_equal (iid, "DwellClickApplet"))
         return FALSE;
 
     return fill_applet (applet);
 }
 
-PANEL_APPLET_BONOBO_FACTORY ("OAFIID:DwellClickApplet_Factory",
-                             PANEL_TYPE_APPLET,
-                             "Dwell Click Factory",
-                             VERSION,
-                             applet_factory,
-                             NULL);
+PANEL_APPLET_OUT_PROCESS_FACTORY ("DwellClickAppletFactory",
+                                  PANEL_TYPE_APPLET,
+                                  "Dwell Click Applet",
+                                  applet_factory,
+                                  NULL)
